Learn R Programming

accrual (version 1.1)

accrual-package: Bayesian Accrual prediction

Description

Description: Subject recruitment for medical research is challenging. Slow patient accrual leads to delay in research.Accrual monitoring during the process of recruitment is critical. Researchers need reliable tools to manage the accrual rate.We developed a Bayesian method that integrates researcher's experience on previous trials and data from the current study,providing reliable prediction on accrual rate for clinical studies.In this R package, we present functions for Bayesian accrual prediction which can be easily used by statisticiana and clinical researcher.s.

Arguments

Details

Package:
accrual
Type:
Package
Version:
1.1
Date:
2015-06-08
License:
GPL-2
There are major three funtions in the package. The accrual.gui function provide the gui version.

References

Gajewski BJ, Simon SD, Carlson SE (2008). Predicting accrual in clinical trials with Bayesian posterior predictive distributions. Stat Med. 27(13):2328-40.

Examples

Run this code
accrual.n(n=300, T=36, P=0.5, m=100, tm=10,Tp=36)
accrual.T(n=300, T=36, P=0.5, m=100, tm=10,np=300)
accrual.plots(accrual.data)
accrual.gui()

Run the code above in your browser using DataLab