Learn R Programming

accrual (version 1.1)

accrual.T.plot: Prediction of Time.

Description

Prediction of time frame for a certain nubmer of subjects.

Usage

accrual.T.plot(n, T, P, m,tm,np)

Arguments

n
Total sample size
T
Total planned time
P
Research's confidence in the accrual process, range 0-1
m
Subject been recruited
tm
Time to now
np
The specific number of subjects want to be predicted

Examples

Run this code
accrual.T.plot(n=300, T=36, P=0.5, m=100, tm=10, np=300) 

Run the code above in your browser using DataLab