Learn R Programming

accrual (version 1.1)

accrual.n.plot: Prediction of Accrual in Fixed Time Frame

Description

Produce a plot and output for prediction of the number of subjects can be recruited in a fixed time frame

Usage

accrual.n.plot(n, T, P, m, tm,Tp)

Arguments

n
Total sample size
T
Total planned time
P
Research's confidence in the accrual process, range 0-1
m
Subject been recruited
tm
Time to now
Tp
The specific time that want to predict the recruitment

Examples

Run this code
 accrual.n.plot(n=300, T=36, P=0.5, m=100, tm=10, Tp=36) 

Run the code above in your browser using DataLab