Learn R Programming

accrual (version 1.1)

accrual.plots: Dignostic Plots

Description

The diagnostic panel shows four figures that help to understand the data distribution. The figure on the top left is the exponential quantile plot, which checks whether the distribution of waiting times is exponential. The top right figure shows the histogram of the waiting times, with the red line is the theoretical exponential distribution. The figure of waiting time verse cumulative accrual time is shown on the bottom left. The figure of total accrual verse cumulative accrual time is shown on the bottom right.

Usage

accrual.plots(w)

Arguments

w
The accrual data set.

Examples

Run this code
accrual.plots(accrual.data)

Run the code above in your browser using DataLab